@@ -228,7 +228,7 @@ class BeaconAPI(object):
             self._debug('< x-typehint: %s' % r.headers['x-typehint'])
         if r.status_code != 200:
             raise BeaconAPIException(code=r.status_code, message=r.reason, body=r.content)
-        if r.headers['content-type'] == 'application/json':
+        if r.headers['content-type'] in ('application/json', 'application/vnd.api+json'):
             return r.json()
         return r.content
 
@@ -237,6 +237,27 @@ class BeaconAPI(object):
     def put(self, _name, **args):      return self.do('put', _name, args)
     def delete(self, _name, **args):   return self.do('delete', _name, args)
 
+    def iter_paged(self, _name, max_items=six.MAXSIZE, **args):
+        cur_items = 0
+
+        while 1:
+            r = self.do('get', _name, args)
+            try:
+                data, links = r['data'], r['links']
+            except (KeyError, TypeError):
+                raise BeaconAPIException(code=400, message="Endpoint did not return JSON:API structure", body=r)
+            for x in data:
+                yield x
+                cur_items += 1
+                if cur_items >= max_items:
+                    return
+
+            if links['next'] is not None:
+                args.update(links['next']['meta'])  # meta will contain page[offset] -> offset
+            else:
+                break
+
+
     def do_async(self, method, _name, args, use_tqdm=False, update_delay=1, status_retries=5):
         """
         execute API call which is expected to return a polling object for progress
